@@ -19,6 +19,8 @@
 #include "generictypes_p.h"
 #include "mmdebug_p.h"
 
+#include <QTimer>
+
 namespace ModemManager
 {
 class ModemManager::BearerProperties::Private
@@ -593,7 +595,6 @@ void ModemManager::ModemPrivate::onPropertiesChanged(const QString &ifaceName, c
     if (ifaceName == QLatin1String(MMQT_DBUS_INTERFACE_MODEM)) {
         QVariantMap::const_iterator it = changedProps.constFind(QLatin1String(MM_MODEM_PROPERTY_SIM));
 
-        it = changedProps.constFind(QLatin1String(MM_MODEM_PROPERTY_SIM));
         if (it != changedProps.constEnd()) {
             Q_EMIT q->simPathChanged(simPath, it->toString());
             simPath = it->toString();
@@ -781,3 +782,6 @@ void ModemManager::ModemPrivate::onStateChanged(int oldState, int newState, uint
     state = (MMModemState)newState;
     Q_EMIT q->stateChanged((MMModemState)oldState, (MMModemState)newState, (MMModemStateChangeReason)reason);
 }
+
+#include "moc_modem.cpp"
+#include "moc_modem_p.cpp"
